Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Resource Access Manager.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for AWS Resource Access Manager - AWS Identity and Access Management

# Actions, Resources, and Condition Keys for AWS Resource Access Manager

AWS Resource Access Manager (service prefix: `ram` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Resource Access Manager
- Resource Types Defined by AWS Resource Access Manager
- Condition Keys for AWS Resource Access Manager

## Actions Defined by AWS Resource Access Manager

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AcceptResourceShareInvitation | Accept the specified resource share invitation | Write | resource-share-invitation* |  |
| ram:ShareOwnerAccountId |
AssociateResourceShare | Associates resource(s) and/or principal(s) to a resource share | Write | resource-share* |  |
| aws:ResourceTag/${TagKey} ram:ResourceShareName ram:AllowsExternalPrincipals ram:Principal ram:RequestedResourceType ram:ResourceArn |
AssociateResourceSharePermission | Associate a Permission with a Resource Share | Write | permission* |  |
resource-share* |  |
| aws:ResourceTag/${TagKey} ram:AllowsExternalPrincipals ram:ResourceShareName ram:PermissionArn |
CreateResourceShare | Create resource share with provided resource(s) and/or principal(s) | Write |  | aws:RequestTag/${TagKey} aws:TagKeys ram:RequestedResourceType ram:ResourceArn ram:RequestedAllowsExternalPrincipals ram:Principal |
DeleteResourceShare | Delete resource share | Write | resource-share* |  |
| aws:ResourceTag/${TagKey} ram:ResourceShareName ram:AllowsExternalPrincipals |
DisassociateResourceShare | Disassociates resource(s) and/or principal(s) from a resource share | Write | resource-share* |  |
| aws:ResourceTag/${TagKey} ram:ResourceShareName ram:AllowsExternalPrincipals ram:Principal ram:RequestedResourceType ram:ResourceArn |
DisassociateResourceSharePermission | Disassociate a Permission from a Resource Share | Write | permission* |  |
resource-share* |  |
| aws:ResourceTag/${TagKey} ram:AllowsExternalPrincipals ram:ResourceShareName ram:PermissionArn |
EnableSharingWithAwsOrganization | Grants permission to access customer's organization and create a SLR in the customer's account | Write |  |  |
GetPermission | Gets the contents of an AWS RAM permission | Read | permission* |  |
| ram:PermissionArn |
GetResourcePolicies | Gets the policies for the specified resources that you own and have shared | Read |  |  |
GetResourceShareAssociations | Get a set of resource share associations from a provided list or with a specified status of the specified type | Read |  |  |
GetResourceShareInvitations | Get resource share invitations by the specified invitation arn or those for the resource share | Read |  |  |
GetResourceShares | Get a set of resource shares from a provided list or with a specified status | Read |  |  |
ListPendingInvitationResources | Lists the resources in a resource share that is shared with you but that the invitation is still pending for | Read | resource-share-invitation* |  |
ListPermissions | Lists the AWS RAM permissions | List |  |  |
ListPrincipals | Lists the principals that you have shared resources with or that have shared resources with you | List |  |  |
ListResourceSharePermissions | List the Permissions associated with a Resource Share | List | resource-share* |  |
| aws:ResourceTag/${TagKey} ram:ResourceShareName ram:AllowsExternalPrincipals |
ListResources | Lists the resources that you added to a resource shares or the resources that are shared with you | List |  |  |
RejectResourceShareInvitation | Reject the specified resource share invitation | Write | resource-share-invitation* |  |
| ram:ShareOwnerAccountId |
TagResource | Tag the specified resources share | Write | resource-share* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Untag the specified resource share | Write | resource-share* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateResourceShare | Update attributes of the resource share | Write | resource-share* |  |
| aws:ResourceTag/${TagKey} ram:ResourceShareName ram:AllowsExternalPrincipals ram:RequestedAllowsExternalPrincipals |

## Resource Types Defined by AWS Resource Access Manager

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
resource-share | `arn:$ { Partition}:ram:$ { Region}:$ { Account}:resource-share/$ { ResourcePath}` | aws:ResourceTag/${TagKey} ram:AllowsExternalPrincipals ram:ResourceShareName
resource-share-invitation | `arn:$ { Partition}:ram:$ { Region}:$ { Account}:resource-share-invitation/$ { ResourcePath}` |
permission | `arn:$ { Partition}:ram::$ { Account}:permission/$ { ResourcePath}` | ram:PermissionArn

## Condition Keys for AWS Resource Access Manager

AWS Resource Access Manager defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Specifies a tag key and value pair that must be used when creating or tagging a resource share. If users don't pass these specific tags, or if they don't specify tags at all, the request fails. | String
aws:ResourceTag/${TagKey} | Indicates that the action can only be performed on resources that have the specified tag key and value pair. | String
aws:TagKeys | Specifies the tag keys that can be used when creating or tagging a resource share | String
ram:AllowsExternalPrincipals | Indicates that the action can only be performed on resource shares that allow or deny sharing with external principals. For example, specify true if the action can only be performed on resource shares that allow sharing with external principals. External principals are AWS accounts that are outside of its AWS organization | Bool
ram:PermissionArn | Indicates that the action can only be performed on a resource using the specified Permission ARN. | Arn
ram:Principal | Principals with the specified format can be associated to or disassociated from a resource share | String
ram:RequestedAllowsExternalPrincipals | The request must have the specified value for 'allowExternalPrincipals'. External principals are AWS accounts that are outside of its AWS Organization | Bool
ram:RequestedResourceType | Indicates that the action can only be performed on the specified resource type | String
ram:ResourceArn | Indicates that the action can only be performed on a resource with the specified ARN. | Arn
ram:ResourceShareName | Indicates that the action can only be performed on a resource share with the specified name. | String
ram:ShareOwnerAccountId | Indicates that the action can only be performed on resource shares owned by a specific account. For example, you can use this condition key to specify which resource share invitations can be accepted or rejected based on the resource share owner’s account ID. | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.